@@ -56,24 +56,21 @@
 #define GTK_MODULES_DISABLED_KEY "disabled-gtk-modules"
 #define GTK_MODULES_ENABLED_KEY  "enabled-gtk-modules"
 
+#define TEXT_SCALING_FACTOR_KEY "text-scaling-factor"
+
 #define FONT_ANTIALIASING_KEY "antialiasing"
 #define FONT_HINTING_KEY      "hinting"
 #define FONT_RGBA_ORDER_KEY   "rgba-order"
-#define FONT_DPI_KEY          "dpi"
 
-/* X servers sometimes lie about the screen's physical dimensions, so we cannot
- * compute an accurate DPI value.  When this happens, the user gets fonts that
- * are too huge or too tiny.  So, we see what the server returns:  if it reports
- * something outside of the range [DPI_LOW_REASONABLE_VALUE,
- * DPI_HIGH_REASONABLE_VALUE], then we assume that it is lying and we use
- * DPI_FALLBACK instead.
+/* As we cannot rely on the X server giving us good DPI information, and
+ * that we don't want multi-monitor screens to have different DPIs (thus
+ * different text sizes), we'll hard-code the value of the DPI
  *
- * See get_dpi_from_gsettings_or_x_server() below, and also
- * https://bugzilla.novell.com/show_bug.cgi?id=217790
+ * See also:
+ * https://bugzilla.novell.com/show_bug.cgi?id=217790•
+ * https://bugzilla.gnome.org/show_bug.cgi?id=643704
  */
 #define DPI_FALLBACK 96
-#define DPI_LOW_REASONABLE_VALUE 50
-#define DPI_HIGH_REASONABLE_VALUE 500
 
 typedef struct _TranslationEntry TranslationEntry;
 typedef void (* TranslationFunc) (GnomeXSettingsManager *manager,
@@ -90,6 +87,7 @@ struct _TranslationEntry {
 
 struct GnomeXSettingsManagerPrivate
 {
+        guint              start_idle_id;
         XSettingsManager **managers;
         GHashTable        *settings;
 
@@ -219,57 +217,18 @@ static TranslationEntry translations [] = {
 };
 
 static double
-dpi_from_pixels_and_mm (int pixels,
-                        int mm)
-{
-        double dpi;
-
-        if (mm >= 1)
-                dpi = pixels / (mm / 25.4);
-        else
-                dpi = 0;
-
-        return dpi;
-}
-
-static double
-get_dpi_from_x_server (void)
-{
-        GdkScreen *screen;
-        double     dpi;
-
-        screen = gdk_screen_get_default ();
-        if (screen != NULL) {
-                double width_dpi, height_dpi;
-
-                width_dpi = dpi_from_pixels_and_mm (gdk_screen_get_width (screen), gdk_screen_get_width_mm (screen));
-                height_dpi = dpi_from_pixels_and_mm (gdk_screen_get_height (screen), gdk_screen_get_height_mm (screen));
-
-                if (width_dpi < DPI_LOW_REASONABLE_VALUE || width_dpi > DPI_HIGH_REASONABLE_VALUE
-                    || height_dpi < DPI_LOW_REASONABLE_VALUE || height_dpi > DPI_HIGH_REASONABLE_VALUE) {
-                        dpi = DPI_FALLBACK;
-                } else {
-                        dpi = (width_dpi + height_dpi) / 2.0;
-                }
-        } else {
-                /* Huh!?  No screen? */
-
-                dpi = DPI_FALLBACK;
-        }
-
-        return dpi;
-}
-
-static double
-get_dpi_from_gsettings_or_x_server (GnomeXSettingsManager *manager)
+get_dpi_from_gsettings (GnomeXSettingsManager *manager)
 {
+	GSettings  *interface_settings;
         double      dpi;
+        double      factor;
 
-        dpi = g_settings_get_double (manager->priv->plugin_settings, FONT_DPI_KEY);
-        if (dpi == 0.0)
-                dpi = get_dpi_from_x_server ();
+	interface_settings = g_hash_table_lookup (manager->priv->settings, INTERFACE_SETTINGS_SCHEMA);
+        factor = g_settings_get_double (interface_settings, TEXT_SCALING_FACTOR_KEY);
 
-        return dpi;
+	dpi = DPI_FALLBACK;
+
+        return dpi * factor;
 }
 
 typedef struct {
@@ -287,18 +246,14 @@ xft_settings_get (GnomeXSettingsManager *manager,
 {
         GsdFontAntialiasingMode antialiasing;
         GsdFontHinting hinting;
-        GsdFontRgbaOrder rgba_order;
-        double dpi;
         gboolean use_rgba = FALSE;
 
         antialiasing = g_settings_get_enum (manager->priv->plugin_settings, FONT_ANTIALIASING_KEY);
         hinting = g_settings_get_enum (manager->priv->plugin_settings, FONT_HINTING_KEY);
-        rgba_order = g_settings_get_enum (manager->priv->plugin_settings, FONT_RGBA_ORDER_KEY);
-        dpi = get_dpi_from_gsettings_or_x_server (manager);
 
         settings->antialias = (antialiasing != GSD_FONT_ANTIALIASING_MODE_NONE);
         settings->hinting = (hinting != GSD_FONT_HINTING_NONE);
-        settings->dpi = dpi * 1024; /* Xft wants 1/1024ths of an inch */
+        settings->dpi = get_dpi_from_gsettings (manager) * 1024; /* Xft wants 1/1024ths of an inch */
         settings->rgba = "rgb";
         settings->hintstyle = "hintfull";
 
@@ -348,8 +303,6 @@ xft_settings_set_xsettings (GnomeXSettingsManager *manager,
                 xsettings_manager_set_string (manager->priv->managers [i], "Xft/HintStyle", settings->hintstyle);
                 xsettings_manager_set_int (manager->priv->managers [i], "Xft/DPI", settings->dpi);
                 xsettings_manager_set_string (manager->priv->managers [i], "Xft/RGBA", settings->rgba);
-                xsettings_manager_set_string (manager->priv->managers [i], "Xft/lcdfilter",
-                                              g_str_equal (settings->rgba, "rgb") ? "lcddefault" : "none");
         }
         gnome_settings_profile_end (NULL);
 }
@@ -409,8 +362,6 @@ xft_settings_set_xresources (GnomeXftSettings *settings)
                                 settings->hintstyle);
         update_property (add_string, "Xft.rgba",
                                 settings->rgba);
-        update_property (add_string, "Xft.lcdfilter",
-                         g_str_equal (settings->rgba, "rgb") ? "lcddefault" : "none");
 
         g_debug("xft_settings_set_xresources: new res '%s'", add_string->str);
 
@@ -519,6 +470,8 @@ start_fontconfig_monitor_idle_cb (GnomeXSettingsManager *manager)
 
         gnome_settings_profile_end (NULL);
 
+        manager->priv->start_idle_id = 0;
+
         return FALSE;
 }
 
@@ -529,7 +482,7 @@ start_fontconfig_monitor (GnomeXSettingsManager  *manager)
 
         fontconfig_cache_init ();
 
-        g_idle_add ((GSourceFunc) start_fontconfig_monitor_idle_cb, manager);
+        manager->priv->start_idle_id = g_idle_add ((GSourceFunc) start_fontconfig_monitor_idle_cb, manager);
 
         gnome_settings_profile_end (NULL);
 }
@@ -581,6 +534,11 @@ xsettings_callback (GSettings             *settings,
         guint             i;
         GVariant         *value;
 
+        if (g_str_equal (key, TEXT_SCALING_FACTOR_KEY)) {
+        	xft_callback (NULL, key, manager);
+        	return;
+	}
+
         trans = find_translation_entry (settings, key);
         if (trans == NULL) {
                 return;
@@ -777,10 +735,6 @@ gnome_xsettings_manager_set_property (GObject        *object,
                                       const GValue   *value,
                                       GParamSpec     *pspec)
 {
-        GnomeXSettingsManager *self;
-
-        self = GNOME_XSETTINGS_MANAGER (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -794,10 +748,6 @@ gnome_xsettings_manager_get_property (GObject        *object,
                                       GValue         *value,
                                       GParamSpec     *pspec)
 {
-        GnomeXSettingsManager *self;
-
-        self = GNOME_XSETTINGS_MANAGER (object);
-
         switch (prop_id) {
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -811,9 +761,6 @@ gnome_xsettings_manager_constructor (GType                  type,
                                      GObjectConstructParam *construct_properties)
 {
         GnomeXSettingsManager      *xsettings_manager;
-        GnomeXSettingsManagerClass *klass;
-
-        klass = GNOME_XSETTINGS_MANAGER_CLASS (g_type_class_peek (GNOME_TYPE_XSETTINGS_MANAGER));
 
         xsettings_manager = GNOME_XSETTINGS_MANAGER (G_OBJECT_CLASS (gnome_xsettings_manager_parent_class)->constructor (type,
                                                                                                                   n_construct_properties,
@@ -825,10 +772,6 @@ gnome_xsettings_manager_constructor (GType                  type,
 static void
 gnome_xsettings_manager_dispose (GObject *object)
 {
-        GnomeXSettingsManager *xsettings_manager;
-
-        xsettings_manager = GNOME_XSETTINGS_MANAGER (object);
-
         G_OBJECT_CLASS (gnome_xsettings_manager_parent_class)->dispose (object);
 }
 
@@ -864,6 +807,9 @@ gnome_xsettings_manager_finalize (GObject *object)
 
         g_return_if_fail (xsettings_manager->priv != NULL);
 
+        if (xsettings_manager->priv->start_idle_id != 0)
+                g_source_remove (xsettings_manager->priv->start_idle_id);
+
         G_OBJECT_CLASS (gnome_xsettings_manager_parent_class)->finalize (object);
 }
 
